@@ -300,7 +300,7 @@ CL_Setenv_f(void)
 
 		else
 		{
-			Com_Printf("%s undefined\n", Cmd_Argv(1), env);
+			Com_Printf("%s undefined\n", Cmd_Argv(1));
 		}
 	}
 }
@@ -899,6 +899,8 @@ CL_Init(void)
 	FS_ExecAutoexec();
 
 	Cbuf_Execute();
+
+	Key_ReadConsoleHistory();
 }
 
 void
@@ -916,6 +918,8 @@ CL_Shutdown(void)
 
 	CL_WriteConfiguration();
 
+	Key_WriteConsoleHistory();
+
 #ifdef CDA
 	CDAudio_Shutdown();
 #endif
