@@ -33,7 +33,7 @@
 #include "crc.h"
 
 /* Should have 4 characters. */
-#define YQ2VERSION "5.30"
+#define YQ2VERSION "5.32"
 
 #define BASEDIRNAME "baseq2"
 
@@ -685,25 +685,11 @@ typedef enum
 	FS_SEARCH_FULL_PATH
 } fsSearchType_t;
 
-void FS_Startup(void);
-void FS_Shutdown(void);
 void FS_DPrintf(const char *format, ...);
-FILE *FS_FileForHandle(fileHandle_t f);
-int FS_FOpenFile(const char *name, fileHandle_t *f, fsMode_t mode);
+int FS_FOpenFile(const char *name, fileHandle_t *f, qboolean gamedir_only);
 void FS_FCloseFile(fileHandle_t f);
 int FS_Read(void *buffer, int size, fileHandle_t f);
 int FS_FRead(void *buffer, int size, int count, fileHandle_t f);
-int FS_Write(const void *buffer, int size, fileHandle_t f);
-void FS_Seek(fileHandle_t f, int offset, fsOrigin_t origin);
-int FS_FTell(fileHandle_t f);
-int FS_Tell(fileHandle_t f);
-qboolean FS_FileExists(char *path);
-void FS_CopyFile(const char *srcPath, const char *dstPath);
-void FS_RenameFile(const char *oldPath, const char *newPath);
-void FS_DeleteFile(const char *path);
-int FS_GetFileList(const char *path, const char *extension,
-		char *buffer, int size, fsSearchType_t searchType);
-char **FS_ListPak(char *find, int *num);
 char **FS_ListFiles(char *findname, int *numfiles,
 		unsigned musthave, unsigned canthave);
 char **FS_ListFiles2(char *findname, int *numfiles,
