@@ -201,7 +201,7 @@ void
 InitGame(void)
 {
 	gi.dprintf("Game is starting up.\n");
-	gi.dprintf("Game is %s.\n", GAMEVERSION);
+	gi.dprintf("Game is %s built on %s.\n", GAMEVERSION, __DATE__);
 
 	gun_x = gi.cvar("gun_x", "0", 0);
 	gun_y = gi.cvar("gun_y", "0", 0);
@@ -251,8 +251,8 @@ InitGame(void)
 	/* items */
 	InitItems();
 
-	Com_sprintf(game.helpmessage1, sizeof(game.helpmessage1), "");
-	Com_sprintf(game.helpmessage2, sizeof(game.helpmessage2), "");
+	game.helpmessage1[0] = 0;
+	game.helpmessage2[0] = 0;
 
 	/* initialize all entities for this game */
 	game.maxentities = maxentities->value;
@@ -648,7 +648,7 @@ ReadField(FILE *f, field_t *field, byte *base)
 				if (len > sizeof(funcStr))
 				{
 					gi.error ("ReadField: function name is longer than buffer (%i chars)",
-							sizeof(funcStr));
+							(int)sizeof(funcStr));
 				}
 
 				fread (funcStr, len, 1, f);
@@ -672,7 +672,7 @@ ReadField(FILE *f, field_t *field, byte *base)
 				if (len > sizeof(funcStr))
 				{
 					gi.error ("ReadField: mmove name is longer than buffer (%i chars)",
-						   	sizeof(funcStr));
+							(int)sizeof(funcStr));
 				}
 
 				fread (funcStr, len, 1, f);
